SystemOrganization addCategory: #BackgammonModel!

Object subclass: #Location
	instanceVariableNames: 'locationType'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Location commentStamp: 'jChizmar 7/11/2015 20:56' prior: 0!
I am the model representation of one of the valid locations on the Backgammon board.  I am the super class of PointLocation, BarLocation, and OffLocation.   

My subclasses are referenced by the Checker to indicate what location on the board the checker is in.  


Public API and Key Messages

- 
  
Internal Representation and Key Implementation Points.

 

!

Location subclass: #BarLocation
	instanceVariableNames: 'pointNumber instance'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

BarLocation class
	instanceVariableNames: 'instance'!

!BarLocation commentStamp: 'jChizmar 7/11/2015 21:08' prior: 0!
I am the model representation of the Bar on the Backgammon board. My superclass isLocation. I am a singleton.

I am referenced by the Checker to indicate that the Checker is located on the Bar.  


Public API and Key Messages

- printOn
  
Internal Representation and Key Implementation Points.

 

!

BarLocation class
	instanceVariableNames: 'instance'!

!BarLocation class methodsFor: 'initialize' stamp: 'jChizmar 7/16/2015 19:44'!
new
    instance isNil ifTrue: [instance := super new].
    ^ instance! !

!BarLocation methodsFor: 'printing' stamp: 'jChizmar 7/11/2015 20:59'!
printOn: aStream
	aStream nextPutAll:'BarLocation Class'.! !

!Location methodsFor: 'accessing' stamp: 'jChizmar 7/16/2015 18:56'!
owningBoard
	^ owningBoard! !

!Location methodsFor: 'accessing' stamp: 'jChizmar 7/16/2015 18:56'!
owningBoard: anObject
	owningBoard := anObject! !

!Location methodsFor: 'printing' stamp: 'jChizmar 7/11/2015 21:00'!
printOn: aStream
	aStream nextPutAll:'Location Class'.! !

Location subclass: #OffLocation
	instanceVariableNames: 'player'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

OffLocation class
	instanceVariableNames: 'instance'!

!OffLocation commentStamp: 'jChizmar 7/11/2015 21:09' prior: 0!
I am the model representation of being off the board in Backgammon. My superclass isLocation. 

I am referenced by the Checker to indicate that the Checker is located on the  board.  


Public API and Key Messages

- player - gets the player that is associated with the off location
- player :- sets the player that is associated with the off location
- printOn
  
Internal Representation and Key Implementation Points.

 

!

OffLocation class
	instanceVariableNames: 'instance'!

!OffLocation class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/16/2015 19:44'!
player: playerIn
	^ self new
	player:playerIn.! !

!OffLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:05'!
player
	^ pointNumber! !

!OffLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:06'!
player: playerIn
	player := playerIn.! !

!OffLocation methodsFor: 'initialize' stamp: 'jChizmar 7/16/2015 19:44'!
playerInit: playerIn
	self player:playerIn.
	^self.! !

!OffLocation methodsFor: 'printing' stamp: 'jChizmar 7/13/2015 20:50'!
printOn:aStream 
	aStream nextPutAll:'Off Location Class -'; 
			  nextPutAll: (String cr); 
			  nextPutAll: 'Player:'; 
			  nextPutAll: ((self player) printString).! !

Location subclass: #PointLocation
	instanceVariableNames: 'pointNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!PointLocation commentStamp: 'jChizmar 7/11/2015 21:09' prior: 0!
I am the model representation of one the Point locations on the Backgammon board. My superclass is location

I am referenced by the Checker to indicate that the Checker is located on a specific Point on the gameboard.


Public API and Key Messages

- pointNumber - gets the number of the point that is associated with the off location
- pointNumber :- sets the number of the point that is associated with the pointlocation
- printOn
  
Internal Representation and Key Implementation Points.

 

!

!PointLocation class methodsFor: 'initialize' stamp: 'jChizmar 7/16/2015 19:44'!
number: pointNumberIn
	^ self new
		pointNumber:pointNumberIn.! !

!PointLocation methodsFor: 'initialize' stamp: 'jChizmar 7/16/2015 19:43'!
number: pointNumberIn.
	self pointNumber:pointNumberIn.
	^self.! !

!PointLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:06'!
pointNumber
	^pointNumber.! !

!PointLocation methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 21:01'!
pointNumber: pointNumberIn
	pointNumber := pointNumberIn.! !

!PointLocation methodsFor: 'printing' stamp: 'jChizmar 7/13/2015 20:55'!
printOn:aStream 
	aStream nextPutAll:'PointLocation Class -'; 
			  nextPutAll: (String cr);  
			  nextPutAll: 'PointNumber:'; 
			  nextPutAll: ((self pointNumber) printString).! !

Object subclass: #MainBoard
	instanceVariableNames: 'player1 player2 player1Checkers player2Checkers points bar player1Off player2Off dice1 dice2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MainBoard commentStamp: 'AhmedSoliman 7/13/2015 14:52' prior: 0!
This is the mainboard of the backgammon game!

!MainBoard class methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 19:32'!
initialize
	| mySelf i |
	mySelf := self new.	"initialize"	"Create Players"
	mySelf player1: (Player new name: 'Jen' checkerColor: Color red).
	mySelf player2: (Player new name: 'Karen' checkerColor: Color black).	"Create Board Locations"	"Create Bar "
	mySelf bar: BarLocation new.	"Create Points"
	i := 1.
	mySelf points: OrderedCollection new.
	[ i < 25 ]
		whileTrue: [ 
			mySelf points add: (PointLocation new number: i).
			i := i + 1 ].	"Add one checker to the model - player 1"
	mySelf player1Checkers: OrderedCollection new.
	mySelf player1Checkers add: (Checker new location: (mySelf points at: 2) color: Color red).	"Add one checker to the model - player 2"
	mySelf player2Checkers: OrderedCollection new.
	mySelf player2Checkers add: (Checker new location: (mySelf points at: 1) color: Color black).	"Create Off"
	mySelf player1Off: ((OffLocation new owningBoard: mySelf) player: mySelf player1).
	mySelf player2Off: ((OffLocation new owningBoard: mySelf) player: mySelf player2).
	
	"Initialize the Dice"
	mySelf dice1:Dice new.
	mySelf dice2:Dice new.
	
	^ mySelf! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
bar
	^ bar! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
bar: anObject
	bar := anObject! !

!MainBoard methodsFor: 'gameMechanics' stamp: 'jChizmar 7/16/2015 20:31'!
checkersOnLocation: locationIn.
	"I return the collection of checkers fthat are currently in play for a given location - consider both Player 1 and Player 2's checkers.  
	This method does not return checkers that are in the 'off' Locations.  If an 'off' location is passed in, the method will return an empty list.  "

	 ^ ((self player1Checkers select:[:checkerOnList | (checkerOnList checkerLocation) = locationIn]), 
		(self player2Checkers select:[:checkerOnList | (checkerOnList checkerLocation) = locationIn])).! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:15'!
dice1
	^ dice1! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:15'!
dice1: anObject
	dice1 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:15'!
dice2
	^ dice2! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:15'!
dice2: anObject
	dice2 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1
	^ player1! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1: anObject
	player1 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1Checkers
	^ player1Checkers! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1Checkers: anObject
	player1Checkers := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player1Off
	^ player1Off! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player1Off: anObject
	player1Off := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2
	^ player2! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2: anObject
	player2 := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2Checkers
	^ player2Checkers! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2Checkers: anObject
	player2Checkers := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
player2Off
	^ player2Off! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
player2Off: anObject
	player2Off := anObject! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 19:58'!
points
	^ points! !

!MainBoard methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:55'!
points: anObject
	points := anObject! !

Object subclass: #MoveCheckerCommand
	instanceVariableNames: 'checkerToMove newLocation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MoveCheckerCommand commentStamp: 'jChizmar 7/14/2015 19:20' prior: 0!
I am a class that implements a Command called Move Checker

My main responsibility is to update the location of a checker to the location selected by the game.

I collaborate by calling methods on the Checker Class.  I take a location as input and I am called by the BGMController Class based on a user action. 

Public API and Key Messages

- execute - this method changes the location of the given checker.

  !

!MoveCheckerCommand class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/14/2015 19:33'!
checker: checkerIn location:locationIn
	^(self new) checker: checkerIn location: locationIn! !

!MoveCheckerCommand methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:33'!
checker: checkerIn location:locationIn
	self checkerToMove:checkerIn.
	self newLocation:locationIn.
	^self.! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
checkerToMove
	^ checkerToMove! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
checkerToMove: anObject
	checkerToMove := anObject! !

!MoveCheckerCommand methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
execute
	"Execute the MoveCheckerCommand"
	self checkerToMove moveChecker: (self newLocation).

	! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
newLocation
	^ newLocation! !

!MoveCheckerCommand methodsFor: 'accessing' stamp: 'jChizmar 7/14/2015 19:22'!
newLocation: anObject
	newLocation := anObject! !

Object subclass: #Observable
	instanceVariableNames: 'observers'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Observable commentStamp: 'AhmedSoliman 7/11/2015 07:00' prior: 0!
Generic Observer pattern
To Do: 
Subclass Me for any model classes that need to notify the view for changes.!

Observable subclass: #Checker
	instanceVariableNames: 'locationOnBoard color'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Checker commentStamp: 'jChizmar 7/14/2015 19:37' prior: 0!
I am the model representation of a checker on the backgammon board.

I hold the location and color of an individual checker. 

I am composed of a location (class in the Backgammon model) and a Smalltalk Color object.  

Public API and Key Messages

- color: - sets the color of the checker
- locationOnBoard: - sets the location of the checker.
- create instance by Checker new: <location> <color>

  
Internal Representation and Key Implementation Points.

    Instance Variables
	color:		<Color>
	moveChecker:		<Location>


!

!Checker class methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
location: locationIn color: colorIn 
	^ self new
		color: colorIn;
		moveChecker: locationIn.! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 21:30'!
checkerLocation
	^ locationOnBoard! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 19:29'!
color
	^ color! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/11/2015 19:29'!
color: colorIn
	color := colorIn! !

!Checker methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:36'!
location: locationIn color: colorInput
	self color:  colorInput.
	self moveChecker:  locationIn.
	^self.! !

!Checker methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 18:41'!
moveChecker: locationIn
	locationOnBoard := locationIn.
	self notifyObservers ! !

!Checker methodsFor: 'printing' stamp: 'jChizmar 7/15/2015 21:30'!
printOn: aStream
	aStream nextPutAll:'Checker Class -'; 
			  nextPutAll: (String cr);   
			  nextPutAll: 'Color:'; 
			  nextPutAll: ((self color) printString);
			  nextPutAll: (String cr); 
			  nextPutAll: 'Location:'; 
			  nextPutAll: ((self checkerLocation) printString ).! !

Observable subclass: #Dice
	instanceVariableNames: 'currentRoll'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Dice commentStamp: 'jChizmar 7/15/2015 22:05' prior: 0!
I am the class that models the rolling of one Dice. 

For the Responsibility part: I generate a random number from 1-6.

For the Collaborators Part: none

Public API and Key Messages

- roll
- initialize
!

!Dice methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 22:22'!
currentRoll
	^ currentRoll! !

!Dice methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 22:45'!
currentRoll: anObject
	currentRoll := anObject.
	self notifyObservers. ! !

!Dice methodsFor: 'executing' stamp: 'jChizmar 7/17/2015 18:57'!
roll
	"models the rolling of a dice"
	|newValue|
	newValue := (6 atRandom).
	 self currentRoll:newValue.
	 ^newValue.
! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/13/2015 15:13'!
addObserver: anObserver
    observers add: anObserver.
	anObserver observable: self! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 06:57'!
initialize
    observers := OrderedCollection new.! !

!Observable methodsFor: 'as yet unclassified' stamp: 'DavidOvergaard 7/16/2015 22:15'!
notifyObservers
    observers do: [ :each | each notify: self ].! !

!Observable methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 06:58'!
removeObserver: anObserver
    observers remove: anObserver.! !

Object subclass: #Observer
	instanceVariableNames: 'observable'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Observer commentStamp: 'AhmedSoliman 7/11/2015 07:01' prior: 0!
An Observer for changes in the observable class!

Observer subclass: #CheckerObserver
	instanceVariableNames: 'locationNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!CheckerObserver commentStamp: 'DavidOvergaard 7/16/2015 22:06' prior: 0!
Observe a checker and update the view!

!CheckerObserver methodsFor: 'as yet unclassified' stamp: 'DavidOvergaard 7/16/2015 22:07'!
notify
	"method to be called when the checker class changed."
	Transcript show:'The Checker I am watching changed!!'.
	Transcript show: String cr.
	Transcript show:observable printString.
	self locationNumber:(observable checkerLocation pointNumber ).! !

Observer subclass: #MockView
	instanceVariableNames: 'locationNumber'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MockView commentStamp: 'jChizmar 7/15/2015 23:11' prior: 0!
I am a class the tests the Model's Observer Pattern for Checker and Dice.



For the Collaborators Part: I observe the Checkers and Dice classes.
Public API and Key Messages

- CheckerChanged   
- DiceChanged
!

!MockView class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 23:30'!
checker:checkerIn	
	^ self new checker: checkerIn.! !

!MockView methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 23:42'!
locationNumber
	^ locationNumber! !

!MockView methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 23:42'!
locationNumber: anObject
	locationNumber := anObject! !

!MockView methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 18:59'!
notify:aString
	"method to be called when the checker class changed."
	Transcript show:'The Checker I am watching changed!!'.
	Transcript show: String cr.
	Transcript show: '----'.
	Transcript show:observable printString.
	self locationNumber:(observable checkerLocation pointNumber ).

! !

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:03'!
notify
    "Action to notify on e.g.: Change in the checker location"
    Transcript show: 'Some things changed in ', observable asString.! !

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:01'!
observable
    ^ observable.! !

!Observer methodsFor: 'as yet unclassified' stamp: 'AhmedSoliman 7/11/2015 07:01'!
observable: anObject
    observable := anObject.! !

Object subclass: #Player
	instanceVariableNames: 'playerName checkerColor'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!Player commentStamp: 'AhmedSoliman 7/13/2015 14:52' prior: 0!
I represent the backgammon players of the game!

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:32'!
createCheckers


	| i myCheckers |
	i:=0.
	myCheckers := Array new.
	(i<14) whileTrue:
	[ 
		myCheckers at: i put: Checker new.
		i := i+1.
	 ]! !

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:36'!
name: nameIn	 checkerColor: colorIn.
	^ self new
		name:nameIn;
		checkerColor:colorIn.! !

!Player class methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:39'!
nameOfPlayer: nameIn	 checkerColor: colorIn.
	^ self new
		nameOfPlayer:nameIn;
		checkerColor:colorIn.! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:12'!
checkerColor
	^ checkerColor! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:12'!
checkerColor: anObject
	checkerColor := anObject! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:39'!
name: nameIn checkerColor:colorIn
	"comment stating purpose of message"

	self nameOfPlayer: nameIn.
	self checkerColor:colorIn.
	^self.! !

!Player methodsFor: 'accessing' stamp: 'jChizmar 7/15/2015 20:43'!
nameOfPlayer
	^ playerName.! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:45'!
nameOfPlayer: nameIn
	"comment stating purpose of message"

	playerName := nameIn.
.! !

!Player methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 20:40'!
nameofPlayer: nameIn checkerColor:colorIn
	"comment stating purpose of message"

	self nameOfPlayer: nameIn.
	self checkerColor:colorIn.
	^self.! !

!Player methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/11/2015 21:08'!
printOn: aStream
	aStream nextPutAll:'PlayerClass'.! !

Object subclass: #RollCommand
	instanceVariableNames: 'dice1 dice2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!RollCommand commentStamp: 'jChizmar 7/17/2015 19:07' prior: 0!
This Command rolls two dice and returns the values.!

!RollCommand class methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/17/2015 19:28'!
dice1:dice1In dice2:dice2In
	^(self new) dice1:dice1In dice2:dice2In.! !

!RollCommand methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:09'!
dice1
	^ dice1! !

!RollCommand methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:09'!
dice1: anObject
	dice1 := anObject! !

!RollCommand methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 19:14'!
dice1: dice1In dice2:dice2In
	self dice1:dice1In.
	self dice2:dice2In.
	^self.! !

!RollCommand methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:09'!
dice2
	^ dice2! !

!RollCommand methodsFor: 'accessing' stamp: 'jChizmar 7/17/2015 19:09'!
dice2: anObject
	dice2 := anObject! !

!RollCommand methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 19:12'!
execute
	"Execute the Roll Command"
	dice1 roll.
	dice2 roll.
	! !

TestCase subclass: #CheckerTestCase
	instanceVariableNames: 'checkerObserver checkerOnBar checkerOnPoint mockCheckerView barLocation pointLocation movableChecker'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!CheckerTestCase methodsFor: 'testing' stamp: 'jChizmar 7/17/2015 18:54'!
setUp
	barLocation := BarLocation new .
	pointLocation := PointLocation new number:1.
	checkerOnPoint := Checker new location: pointLocation color:  (Color red).
	checkerOnBar := Checker new location: barLocation color:  (Color red).
	
	movableChecker := Checker new location: barLocation color:  (Color blue).
	movableChecker initialize .
	mockCheckerView := MockView new.
	movableChecker addObserver: mockCheckerView.! !

!CheckerTestCase methodsFor: 'testing' stamp: 'AhmedSoliman 7/13/2015 14:59'!
testInitialize
	"Create a Checker"
	
	Transcript show:(checkerOnPoint printString).
	self assert: (checkerOnPoint isNotNil ).
	self assert:(checkerOnPoint color = Color red).

! !

!CheckerTestCase methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 23:49'!
testObserverWithCommand
	"test moving the checker from bar to point"
	movableChecker moveChecker: pointLocation ! !

!CheckerTestCase methodsFor: 'testing' stamp: 'jChizmar 7/15/2015 21:30'!
testPrinting
	"Tests for printing out Checker"
	
	Transcript show:(checkerOnBar printString).
	self assert:(checkerOnBar printString = ('Checker Class -', (String cr) , 'Color:Color red', (String cr) , 'Location:BarLocation Class') ).
	
	self assert:(((checkerOnPoint checkerLocation) printString) = ('PointLocation Class -', (String cr), 'PointNumber:', '1')).

	! !

TestCase subclass: #DiceTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!DiceTest methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 22:44'!
testDice
	"comment stating purpose of message"
	|myRoll myCollection i myDice|
	myDice := Dice new.
	myRoll := myDice roll.
	self assert:(myRoll >=1 & myRoll <=6).
	myCollection := OrderedCollection new.
	i := 0.
	[i<100] whileTrue:[
		myRoll := myDice roll.
		self assert:(myRoll >=1 & myRoll <=6).
		myCollection add: myRoll.
		i  :=i+1.
	].
 
	! !

TestCase subclass: #MainBoardTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MainBoardTest methodsFor: 'testing' stamp: 'jChizmar 7/16/2015 20:46'!
testCheckersAtLocation
	"testing finding the checkers for a given location"
	
	|mainBoardToTest locationList i|
	mainBoardToTest := MainBoard initialize.
	
	"Test with just the Initizlized Board Settings"
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:2).
	self assert:( locationList size = 1).
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:3).
	self assert:( locationList size = 0).
	
	"Test with Different Combos of Checkers"
	
	"Multiple Player 1 checkers on the same point one on a different point"
	i:=0.
	[i<5  ] whileTrue:[
		mainBoardToTest player1Checkers addLast: (Checker new location: (mainBoardToTest points at: 5) color: Color red).
		i:=i+1.
	].
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:5).
	self assert:( locationList size = 5).
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:2).
	self assert:( locationList size = 1).
	
	"Multiple Player 2 checkers on the same point one on a different point"
	i:=0.
	[i<5  ] whileTrue:[
		mainBoardToTest player2Checkers addLast: (Checker new location: (mainBoardToTest points at: 6) color: Color red).
		i:=i+1.
	].
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:6).
	self assert:( locationList size = 5).

	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:1).
	self assert:( locationList size = 1).
	
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:5).
	self assert:( locationList size = 5).
	
	"Check for Player 1 checkers on the Bar"
	
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:5).
	(locationList at:1) moveChecker: mainBoardToTest bar.
	locationList := mainBoardToTest checkersOnLocation:(mainBoardToTest bar).
	self assert:( locationList size = 1 & (locationList at:1) color = Color red).
	
	
	
	"Check for Player 1 & 2 checkers on the Bar"
	locationList := mainBoardToTest checkersOnLocation: (mainBoardToTest points at:6).
	(locationList at:1) moveChecker: mainBoardToTest bar.
	locationList := mainBoardToTest checkersOnLocation:(mainBoardToTest bar).
	self assert:( locationList size = 2).
	! !

!MainBoardTest methodsFor: 'testing' stamp: 'jChizmar 7/15/2015 23:18'!
testMainBoardInit
	"comment stating purpose of message"
	
	|myMainBoard|
	
	myMainBoard := MainBoard initialize.
	self assert: ((myMainBoard player1Checkers) size = 1).
	self assert: ((myMainBoard player2Checkers) size = 1).
	self assert: (((myMainBoard player1Checkers at:1) color = Color red) ).
	self assert: (((myMainBoard player2Checkers at:1) color = Color black) ).
	self assert: (myMainBoard bar = BarLocation new).
	self assert: ((myMainBoard points) size = 24).
	self assert: ((myMainBoard points at: 4) pointNumber = 4).
	self assert: ((myMainBoard points at: 1) pointNumber = 1).
	self assert: ((myMainBoard player1) nameOfPlayer = 'Jen').
	self assert: ((myMainBoard player2) nameOfPlayer = 'Karen').! !

!MainBoardTest methodsFor: 'testing' stamp: 'jChizmar 7/15/2015 23:47'!
testObserverSimple
	"comment stating purpose of message"

	|myObserver myChecker barLocation|
	barLocation := BarLocation new.
	myChecker := Checker new location: barLocation color:  (Color red).
	
	myObserver := MockView new.
	myChecker addObserver: myObserver.
	
	myChecker moveChecker: (PointLocation new number:3).
	self assert:(myObserver locationNumber = 3).! !

!MainBoardTest methodsFor: 'testing' stamp: 'jChizmar 7/15/2015 23:49'!
testObserverWithCommand
	"comment stating purpose of message"

	|myMoveCommand myObserver myMainBoard|
	
	myMainBoard := MainBoard initialize.
	myObserver := MockView new .
	(myMainBoard player1Checkers at: 1) addObserver: myObserver.
	
	myMoveCommand := MoveCheckerCommand new checker: (myMainBoard player1Checkers at: 1) location: (myMainBoard points at:20).
	myMoveCommand execute.
	self assert:((myMainBoard player1Checkers at: 1) checkerLocation pointNumber = 20).
	self assert:(myObserver locationNumber = 20).! !

TestCase subclass: #MoveCheckerCommandTestCase
	instanceVariableNames: 'barLocation pointLocation checkerOnPoint checkerOnBar'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:27'!
setUp
	"Setup the Objects for Testing"
	barLocation := BarLocation new .
	pointLocation := PointLocation new number:1.
	checkerOnPoint := Checker new location: pointLocation color:  (Color red).
	checkerOnBar := Checker new location: barLocation color:  (Color red).! !

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/15/2015 21:30'!
testInitialize
	"Tests the Initialization and setup of the MoveCheckerCommand"
	
	|moveCheckerCommand|
	moveCheckerCommand := (MoveCheckerCommand new) checker:checkerOnPoint  location: barLocation.
	moveCheckerCommand execute.
	self assert:((checkerOnPoint checkerLocation) = barLocation).

! !

!MoveCheckerCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/14/2015 19:29'!
testMoveChecker
	"This tests the move of a checker from locaiton to location"
! !

TestCase subclass: #PlayerTestCase
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!PlayerTestCase methodsFor: 'as yet unclassified' stamp: 'jChizmar 7/15/2015 20:46'!
testInitialize
	"comment stating purpose of message"

	|myPlayer|
	
	myPlayer := Player nameOfPlayer:'Jen' checkerColor:Color red.
	self assert:(myPlayer nameOfPlayer = 'Jen').! !

TestCase subclass: #RollCommandTestCase
	instanceVariableNames: 'barLocation pointLocation checkerOnPoint checkerOnBar testDice1 testDice2'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'BackgammonModel'!

!RollCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 19:27'!
setUp
	"Setup the Objects for Testing"
	testDice1:=Dice new.
	testDice2:=Dice new.! !

!RollCommandTestCase methodsFor: 'initialize' stamp: 'jChizmar 7/17/2015 19:32'!
testInitialize
	"Tests the Initialization and setup of the MoveCheckerCommand"
	
	|rollCommand|
	rollCommand := (RollCommand new) dice1:testDice1  dice2:testDice2.
	rollCommand execute.
	self assert:(rollCommand dice1 currentRoll >=1 & rollCommand dice1 currentRoll <=6).
	self assert:(rollCommand dice2 currentRoll  >=1 & rollCommand dice2 currentRoll  <=6).
! !
MainBoard initialize!
